[tor-commits] r24550: {arm} Fixing comment typos and spelling mistakes. (in arm/trunk/src: interface/connections util)

Damian Johnson atagar1 at gmail.com
Sun Apr 3 18:03:25 UTC 2011


Author: atagar
Date: 2011-04-03 18:03:25 +0000 (Sun, 03 Apr 2011)
New Revision: 24550

Modified:
   arm/trunk/src/interface/connections/circEntry.py
   arm/trunk/src/interface/connections/connEntry.py
   arm/trunk/src/interface/connections/entries.py
   arm/trunk/src/util/connections.py
   arm/trunk/src/util/enum.py
Log:
Fixing comment typos and spelling mistakes.



Modified: arm/trunk/src/interface/connections/circEntry.py
===================================================================
--- arm/trunk/src/interface/connections/circEntry.py	2011-04-03 15:05:14 UTC (rev 24549)
+++ arm/trunk/src/interface/connections/circEntry.py	2011-04-03 18:03:25 UTC (rev 24550)
@@ -62,7 +62,7 @@
   def update(self, status, path):
     """
     Our status and path can change over time if the circuit is still in the
-    process of being built. Updates these attributs of our relay.
+    process of being built. Updates these attributes of our relay.
     
     Arguments:
       status - new status of the circuit
@@ -140,7 +140,7 @@
 
 class CircLine(connEntry.ConnectionLine):
   """
-  An inidividual hop in a circuit. This overwrites the displayed listing, but
+  An individual hop in a circuit. This overwrites the displayed listing, but
   otherwise makes use of the ConnectionLine attributes (for the detail display,
   caching, etc).
   """

Modified: arm/trunk/src/interface/connections/connEntry.py
===================================================================
--- arm/trunk/src/interface/connections/entries.py	2011-04-03 15:05:14 UTC (rev 24549)
+++ arm/trunk/src/interface/connections/entries.py	2011-04-03 18:03:25 UTC (rev 24550)
@@ -156,7 +156,7 @@
   
   def getDescriptor(self, width):
     """
-    Provides a list of DrawEntry instances with descriptor informatoin for
+    Provides a list of DrawEntry instances with descriptor information for
     this connection.
     
     Arguments:

Modified: arm/trunk/src/util/connections.py
===================================================================
--- arm/trunk/src/util/connections.py	2011-04-03 15:05:14 UTC (rev 24549)
+++ arm/trunk/src/util/connections.py	2011-04-03 18:03:25 UTC (rev 24550)
@@ -664,7 +664,7 @@
     
     if not lsofResults and self.failureCount != -1:
       # lsof query failed and we aren't yet sure if it's possible to
-      # successfuly get results on this platform
+      # successfully get results on this platform
       self.failureCount += 1
       self.isResolving = False
       return
@@ -699,7 +699,7 @@
                     results[portMatch].append(newEntry)
                   else: results[portMatch] = [newEntry]
       
-      # making the lsof call generated an extranious sh entry for our own connection
+      # making the lsof call generated an extraneous sh entry for our own connection
       if ourConnection:
         for ourPort in ourConnection:
           if ourPort in results:

Modified: arm/trunk/src/util/enum.py
===================================================================
--- arm/trunk/src/util/enum.py	2011-04-03 15:05:14 UTC (rev 24549)
+++ arm/trunk/src/util/enum.py	2011-04-03 18:03:25 UTC (rev 24550)
@@ -40,7 +40,7 @@
 
 class Enum:
   """
-  Basic enumaration.
+  Basic enumeration.
   """
   
   def __init__(self, *args):



More information about the tor-commits mailing list
--- arm/trunk/src/interface/connections/connEntry.py	2011-04-03 15:05:14 UTC (rev 24549)
+++ arm/trunk/src/interface/connections/connEntry.py	2011-04-03 18:03:25 UTC (rev 24550)
@@ -355,7 +355,7 @@
     """
     
     # This is used to scrub private information from the interface. Relaying
-    # etiquette (and wiretaping laws) say these are bad things to look at so
+    # etiquette (and wiretapping laws) say these are bad things to look at so
     # DON'T CHANGE THIS UNLESS YOU HAVE A DAMN GOOD REASON!
     
     myType = self.getType()
@@ -384,7 +384,7 @@
   def getType(self):
     """
     Provides our best guess at the current type of the connection. This
-    depends on consensus results, our current client circuts, etc. Results
+    depends on consensus results, our current client circuits, etc. Results
     are cached until this entry's display is reset.
     """
     
@@ -588,7 +588,7 @@
       
       # Showing the fingerprint (which has the width of 42) has priority over
       # an expanded address field. Hence check if we either have space for
-      # both or wouldn't be showing the fingerprint reguardless.
+      # both or wouldn't be showing the fingerprint regardless.
       
       isExpandedAddrVisible = width > usedSpace + 28
       if isExpandedAddrVisible and CONFIG["features.connection.showColumn.fingerprint"]:
@@ -667,7 +667,7 @@
   
   def _getDetailContent(self, width):
     """
-    Provides a list with detailed information for this connectoin.
+    Provides a list with detailed information for this connection.
     
     Arguments:
       width - max length of lines
@@ -679,7 +679,7 @@
     
     # Remaining data concerns the consensus results, with three possible cases:
     # - if there's a single match then display its details
-    # - if there's multiple potenial relays then list all of the combinations
+    # - if there's multiple potential relays then list all of the combinations
     #   of ORPorts / Fingerprints
     # - if no consensus data is available then say so (probably a client or
     #   exit connection)
@@ -714,7 +714,7 @@
           flags = nsLines[1][2:]
         
         # The network status exit policy doesn't exist for older tor versions.
-        # If unavailble we'll need the full exit policy which is on the
+        # If unavailable we'll need the full exit policy which is on the
         # descriptor (if that's available).
         
         exitPolicy = "unknown"
@@ -764,7 +764,7 @@
       
       if allMatches:
         # multiple matches
-        lines[2] = "Muliple matches, possible fingerprints are:"
+        lines[2] = "Multiple matches, possible fingerprints are:"
         
         for i in range(len(allMatches)):
           isLastLine = i == 3
@@ -846,8 +846,8 @@
           dstHostname = self.foreign.getHostname()
           
           if dstHostname:
             # determines the full space availabe, taking into account the ", "
             # dividers if there's multipe pieces of extra data
             
             maxHostnameSpace = spaceAvailable - 2 * len(extraInfo)
             dstHostname = uiTools.cropStr(dstHostname, maxHostnameSpace)
@@ -846,8 +846,8 @@
           
           if dstHostname:
-            # determines the full space availabe, taking into account the ", "
-            # dividers if there's multipe pieces of extra data
+            # determines the full space available, taking into account the ", "
+            # dividers if there's multiple pieces of extra data
             
             maxHostnameSpace = spaceAvailable - 2 * len(extraInfo)

Modified: arm/trunk/src/interface/connections/entries.py
===================================================================